@@ -3,23 +3,21 @@
 #include <QtCore>
 
 LetterRepeatingCheck::LetterRepeatingCheck()
-: letterNumberToTrigger(0)
+	: letterNumberToTrigger(0)
 {
 }
 
-bool LetterRepeatingCheck::run(QString msg) 
+bool LetterRepeatingCheck::run(QString msg)
 {
 	msg = msg.simplified().remove(" ");
 	QRegExp e(QString(".*(.)\\1{%1,}.*").arg(letterNumberToTrigger-1));
 	if(e.isValid()) {
-		if(e.exactMatch(msg)) { 
-			return true; 
-		}
-		else {
+		if(e.exactMatch(msg)) {
+			return true;
+		} else {
 			return false;
 		}
-	}
-	else { 
+	} else {
 //		qDebug() << "The current Letter Repeating RegExp is invalid" << endl;
 		return false;
 	}
