@@ -6,23 +6,25 @@ UrlCheck::UrlCheck()
 {
 }
 
-bool UrlCheck::run(QString msg) 
+bool UrlCheck::run(QString msg)
 {
 	msg = msg.toLower();
-	
+
 	QStringListIterator it1(urlStrings);
-	
+
 	while (it1.hasNext()) {
 		if(msg.contains(it1.next())) {
 			QStringListIterator it2(urlExceptionStrings);
 			bool exception = false;
 			while (it2.hasNext()) {
-				if(msg.contains(it2.next())) { 
-					exception = true; 
+				if(msg.contains(it2.next())) {
+					exception = true;
 					break;
 				}
 			}
-			if(!exception) { return true; }
+			if(!exception) {
+				return true;
+			}
 		}
 	}
 	return false;
