@@ -57,6 +57,7 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 		myLog->init();
 		// 		myGuiInterface->setSession(session);
 	}
+	myGuiInterface->getMyGuiLog()->setMySqliteLogFileName(myLog->getMySqliteLogFileName());
 
 	// #ifdef __APPLE__
 	// 	setWindowModality(Qt::ApplicationModal);
@@ -71,6 +72,17 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 	this->setWindowIcon(QIcon(myAppDataPath+"gfx/gui/misc/windowicon.png"));
 
 	this->setStatusBar(0);
+
+#ifdef GUI_800x480
+	this->menubar->setStyleSheet("QMenuBar { background-color: #4B4B4B; font-size:20px; border-width: 0px;} QMenuBar::item { color: #F0F0F0; }");
+
+	centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg_800x480.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
+
+	pushButtonStart_Local_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:20px; border-width: 0px;}");
+	pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:20px; border-width: 0px;}");
+	pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:20px; border-width: 0px;}");
+	pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 3px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:20px; border-width: 0px;}");
+#else
 	this->menubar->setStyleSheet("QMenuBar { background-color: #4B4B4B; font-size:12px; border-width: 0px;} QMenuBar::item { color: #F0F0F0; }");
 
 	centralwidget->setStyleSheet(".QWidget { background-image: url(\""+myAppDataPath+"gfx/gui/misc/startwindowbg.png\"); background-position: bottom center; background-origin: content; background-repeat: no-repeat;}");
@@ -79,6 +91,7 @@ startWindowImpl::startWindowImpl(ConfigFile *c, Log *l)
 	pushButtonInternet_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
 	pushButton_Create_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
 	pushButton_Join_Network_Game->setStyleSheet("QPushButton { text-align:left; font-weight:bold; padding-left: 1px; padding-bottom: 3px; padding-top: 3px; padding-right: 3px; background-color: #4B4B4B; color: #F0F0F0; font-size:12px; border-width: 0px;}");
+#endif
 
 
 	// 	Dialogs
@@ -1060,6 +1073,18 @@ void startWindowImpl::networkMessage(unsigned msgId)
 		msgText = tr("An error occurred while reporting the avatar.");
 	}
 	break;
+	case MSG_NET_GAMENAME_REPORT_ACCEPTED: {
+		msgText = tr("The game name report was accepted by the server. Thank you.");
+	}
+	break;
+	case MSG_NET_GAMENAME_REPORT_DUP: {
+		msgText = tr("This game name was already reported by another player.");
+	}
+	break;
+	case MSG_NET_GAMENAME_REPORT_REJECTED: {
+		msgText = tr("An error occurred while reporting the game name.");
+	}
+	break;
 	default:
 		;
 		break;
