@@ -173,25 +173,26 @@ ClientStateStartServerListDownload::~ClientStateStartServerListDownload()
 void
 ClientStateStartServerListDownload::Enter(boost::shared_ptr<ClientThread> client)
 {
-	const ClientContext &context = client->GetContext();
-	path tmpServerListPath(context.GetCacheDir());
-	string serverListUrl(context.GetServerListUrl());
-	// Retrieve the file name from the URL.
-	size_t pos = serverListUrl.find_last_of('/');
-	if (context.GetCacheDir().empty() || serverListUrl.empty() || pos == string::npos || ++pos >= serverListUrl.length()) {
-		throw ClientException(__FILE__, __LINE__, ERR_SOCK_INVALID_SERVERLIST_URL, 0);
-	}
-	tmpServerListPath /= serverListUrl.substr(pos);
+	path tmpServerListPath(client->GetCacheServerListFileName());
 	if (exists(tmpServerListPath)) {
-		// Always download the current server list.
-		// If a previous file exists, delete it.
-		remove(tmpServerListPath);
+		// Download the current server list once a day.
+		// If the previous file is older than one day, delete it.
+		// Also delete the file if it is empty.
+		if (file_size(tmpServerListPath) == 0 || (last_write_time(tmpServerListPath) + 86400 < time(NULL))) {
+			remove(tmpServerListPath);
+		}
+	}
+
+	if (exists(tmpServerListPath)) {
+		// Use the existing server list.
+		client->SetState(ClientStateReadingServerList::Instance());
+	} else {
+		// Download the server list.
+		boost::shared_ptr<DownloadHelper> downloader(new DownloadHelper);
+		downloader->Init(client->GetContext().GetServerListUrl(), tmpServerListPath.directory_string());
+		ClientStateDownloadingServerList::Instance().SetDownloadHelper(downloader);
+		client->SetState(ClientStateDownloadingServerList::Instance());
 	}
-	// Download server list.
-	boost::shared_ptr<DownloadHelper> downloader(new DownloadHelper);
-	downloader->Init(serverListUrl, tmpServerListPath.directory_string());
-	ClientStateDownloadingServerList::Instance().SetDownloadHelper(downloader);
-	client->SetState(ClientStateDownloadingServerList::Instance());
 }
 
 void
@@ -493,8 +494,9 @@ ClientStateStartConnect::HandleConnect(const boost::system::error_code& ec, boos
 							++m_remoteEndpointIterator,
 							client));
 		} else {
-			if (ec != boost::asio::error::operation_aborted)
+			if (ec != boost::asio::error::operation_aborted) {
 				throw ClientException(__FILE__, __LINE__, ERR_SOCK_CONNECT_FAILED, ec.value());
+			}
 		}
 	}
 }
@@ -751,11 +753,11 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 	} else if (tmpPacket->GetMsg()->present == PokerTHMessage_PR_reportAvatarAckMessage) {
 		ReportAvatarAckMessage_t *netReportAck = &tmpPacket->GetMsg()->choice.reportAvatarAckMessage;
 		unsigned msgCode;
-		switch (netReportAck->reportResult) {
-		case reportResult_avatarReportAccepted:
+		switch (netReportAck->reportAvatarResult) {
+		case reportAvatarResult_avatarReportAccepted:
 			msgCode = MSG_NET_AVATAR_REPORT_ACCEPTED;
 			break;
-		case reportResult_avatarReportDuplicate:
+		case reportAvatarResult_avatarReportDuplicate:
 			msgCode = MSG_NET_AVATAR_REPORT_DUP;
 			break;
 		default:
@@ -763,6 +765,21 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 			break;
 		}
 		client->GetCallback().SignalNetClientMsgBox(msgCode);
+	} else if (tmpPacket->GetMsg()->present == PokerTHMessage_PR_reportGameAckMessage) {
+		ReportGameAckMessage_t *netReportAck = &tmpPacket->GetMsg()->choice.reportGameAckMessage;
+		unsigned msgCode;
+		switch (netReportAck->reportGameResult) {
+		case reportGameResult_gameReportAccepted:
+			msgCode = MSG_NET_GAMENAME_REPORT_ACCEPTED;
+			break;
+		case reportGameResult_gameReportDuplicate:
+			msgCode = MSG_NET_GAMENAME_REPORT_DUP;
+			break;
+		default:
+			msgCode = MSG_NET_GAMENAME_REPORT_REJECTED;
+			break;
+		}
+		client->GetCallback().SignalNetClientMsgBox(msgCode);
 	} else if (tmpPacket->GetMsg()->present == PokerTHMessage_PR_statisticsMessage) {
 		StatisticsMessage_t *netStatistics = &tmpPacket->GetMsg()->choice.statisticsMessage;
 
@@ -844,6 +861,13 @@ ClientStateStartSession::InternalHandlePacket(boost::shared_ptr<ClientThread> cl
 			InitMessage_t *netInit = &init->GetMsg()->choice.initMessage;
 			netInit->requestedVersion.major = NET_VERSION_MAJOR;
 			netInit->requestedVersion.minor = NET_VERSION_MINOR;
+			if (!context.GetSessionGuid().empty()) {
+				netInit->myLastSessionId =
+					OCTET_STRING_new_fromBuf(
+						&asn_DEF_OCTET_STRING,
+						context.GetSessionGuid().c_str(),
+						(int)context.GetSessionGuid().length());
+			}
 			if (!context.GetServerPassword().empty()) {
 				netInit->authServerPassword =
 					OCTET_STRING_new_fromBuf(
