@@ -46,12 +46,14 @@ static bool LessThanPlayerHandStartMoney(const boost::shared_ptr<PlayerInterface
 }
 
 
-ServerGame::ServerGame(boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const string &name, const string &pwd, const GameData &gameData, unsigned adminPlayerId, GuiInterface &gui, ConfigFile &playerConfig)
+ServerGame::ServerGame(boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const string &name, const string &pwd, const GameData &gameData,
+					   unsigned adminPlayerId, unsigned creatorPlayerDBId, GuiInterface &gui, ConfigFile &playerConfig)
 	: m_adminPlayerId(adminPlayerId), m_lobbyThread(lobbyThread), m_gui(gui),
 	  m_gameData(gameData), m_curState(NULL), m_id(id), m_name(name),
-	  m_password(pwd), m_playerConfig(playerConfig), m_gameNum(1),
-	  m_curPetitionId(1), m_voteKickTimer(lobbyThread->GetIOService()),
-	  m_stateTimer1(lobbyThread->GetIOService()), m_stateTimer2(lobbyThread->GetIOService())
+	  m_password(pwd), m_creatorPlayerDBId(creatorPlayerDBId), m_playerConfig(playerConfig),
+	  m_gameNum(1), m_curPetitionId(1), m_voteKickTimer(lobbyThread->GetIOService()),
+	  m_stateTimer1(lobbyThread->GetIOService()), m_stateTimer2(lobbyThread->GetIOService()),
+	  m_isNameReported(false)
 {
 	LOG_VERBOSE("Game object " << GetId() << " created.");
 }
@@ -86,6 +88,12 @@ ServerGame::GetName() const
 	return m_name;
 }
 
+unsigned
+ServerGame::GetCreatorDBId() const
+{
+	return m_creatorPlayerDBId;
+}
+
 void
 ServerGame::AddSession(boost::shared_ptr<SessionData> session)
 {
@@ -717,6 +725,18 @@ ServerGame::GetAndResetReactivatePlayers()
 	return tmpList;
 }
 
+void
+ServerGame::SetNameReported()
+{
+	m_isNameReported = true;
+}
+
+bool
+ServerGame::IsNameReported() const
+{
+	return m_isNameReported;
+}
+
 void
 ServerGame::AddComputerPlayer(boost::shared_ptr<PlayerData> player)
 {
