@@ -178,6 +178,14 @@ public:
 		m_server.SendReportAvatarResult(requestId, replyId, false);
 	}
 
+	virtual void ReportGameSuccess(unsigned requestId, unsigned replyId) {
+		m_server.SendReportGameResult(requestId, replyId, true);
+	}
+
+	virtual void ReportGameFailed(unsigned requestId, unsigned replyId) {
+		m_server.SendReportGameResult(requestId, replyId, false);
+	}
+
 private:
 	ServerLobbyThread &m_server;
 };
@@ -486,6 +494,13 @@ ServerLobbyThread::HandleGameRetrieveAvatar(boost::shared_ptr<SessionData> sessi
 	HandleNetPacketRetrieveAvatar(session, retrieveAvatar);
 }
 
+void
+ServerLobbyThread::HandleGameReportGame(boost::shared_ptr<SessionData> session, const ReportGameMessage_t &reportGame)
+{
+	// Someone within a game reportet a game name.
+	HandleNetPacketReportGame(session, reportGame);
+}
+
 void
 ServerLobbyThread::HandleChatRequest(boost::shared_ptr<SessionData> session, const ChatRequestMessage_t &chatRequest)
 {
@@ -509,6 +524,23 @@ ServerLobbyThread::KickPlayerByName(const std::string &playerName)
 	return retVal;
 }
 
+bool
+ServerLobbyThread::RemoveGameByPlayerName(const std::string &playerName)
+{
+	bool retVal = false;
+	boost::shared_ptr<SessionData> session = m_gameSessionManager.GetSessionByPlayerName(playerName);
+
+	if (session) {
+		boost::shared_ptr<ServerGame> game = session->GetGame();
+		if (game) {
+			m_ioService->post(boost::bind(&ServerLobbyThread::InternalRemoveGame, shared_from_this(), game));
+			retVal = true;
+		}
+	}
+
+	return retVal;
+}
+
 string
 ServerLobbyThread::GetPlayerIPAddress(const std::string &playerName) const
 {
@@ -910,6 +942,8 @@ ServerLobbyThread::HandlePacket(boost::shared_ptr<SessionData> session, boost::s
 				HandleNetPacketChatRequest(session, packet->GetMsg()->choice.chatRequestMessage);
 			else if (packet->GetMsg()->present == PokerTHMessage_PR_rejectGameInvitationMessage)
 				HandleNetPacketRejectGameInvitation(session, packet->GetMsg()->choice.rejectGameInvitationMessage);
+			else if (packet->GetMsg()->present == PokerTHMessage_PR_reportGameMessage)
+				HandleNetPacketReportGame(session, packet->GetMsg()->choice.reportGameMessage);
 			else
 				SessionError(session, ERR_SOCK_INVALID_STATE);
 		}
@@ -1270,6 +1304,7 @@ ServerLobbyThread::HandleNetPacketCreateGame(boost::shared_ptr<SessionData> sess
 				password,
 				tmpData,
 				session->GetPlayerData()->GetUniqueId(),
+				session->GetPlayerData()->GetDBId(),
 				GetGui(),
 				m_serverConfig));
 		game->Init();
@@ -1426,6 +1461,45 @@ ServerLobbyThread::HandleNetPacketRejectGameInvitation(boost::shared_ptr<Session
 	}
 }
 
+void
+ServerLobbyThread::HandleNetPacketReportGame(boost::shared_ptr<SessionData> session, const ReportGameMessage_t &report)
+{
+	GameMap::iterator pos = m_gameMap.find(report.reportedGameId);
+
+	if (pos != m_gameMap.end() && session->GetPlayerData()) {
+		boost::shared_ptr<ServerGame> tmpGame(pos->second);
+		if (!tmpGame->IsNameReported()) {
+			// Temporarily note that this game was reported.
+			// This prevents spamming of the game report.
+			tmpGame->SetNameReported();
+			unsigned creatorDBId = tmpGame->GetCreatorDBId();
+			unsigned reporterDBId = session->GetPlayerData()->GetDBId();
+			GetDatabase()->AsyncReportGame(
+				session->GetPlayerData()->GetUniqueId(),
+				tmpGame->GetId(),
+				creatorDBId != 0 ? &creatorDBId : NULL,
+				tmpGame->GetId(),
+				tmpGame->GetName(),
+				reporterDBId != 0 ? &reporterDBId : NULL
+			);
+		} else {
+			boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+			packet->GetMsg()->present = PokerTHMessage_PR_reportGameAckMessage;
+			ReportGameAckMessage_t *netReportAck = &packet->GetMsg()->choice.reportGameAckMessage;
+			netReportAck->reportedGameId = report.reportedGameId;
+			netReportAck->reportGameResult = reportGameResult_gameReportDuplicate;
+			GetSender().Send(session, packet);
+		}
+	} else {
+		boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+		packet->GetMsg()->present = PokerTHMessage_PR_reportGameAckMessage;
+		ReportGameAckMessage_t *netReportAck = &packet->GetMsg()->choice.reportGameAckMessage;
+		netReportAck->reportedGameId = report.reportedGameId;
+		netReportAck->reportGameResult = reportGameResult_gameReportInvalid;
+		GetSender().Send(session, packet);
+	}
+}
+
 void
 ServerLobbyThread::AuthChallenge(boost::shared_ptr<SessionData> session, const string &secret)
 {
@@ -1603,7 +1677,23 @@ ServerLobbyThread::SendReportAvatarResult(unsigned byPlayerId, unsigned reported
 		packet->GetMsg()->present = PokerTHMessage_PR_reportAvatarAckMessage;
 		ReportAvatarAckMessage_t *netReportAck = &packet->GetMsg()->choice.reportAvatarAckMessage;
 		netReportAck->reportedPlayerId = reportedPlayerId;
-		netReportAck->reportResult = success ? reportResult_avatarReportAccepted : reportResult_avatarReportInvalid;
+		netReportAck->reportAvatarResult = success ? reportAvatarResult_avatarReportAccepted : reportAvatarResult_avatarReportInvalid;
+		GetSender().Send(session, packet);
+	}
+}
+
+void
+ServerLobbyThread::SendReportGameResult(unsigned byPlayerId, unsigned reportedGameId, bool success)
+{
+	boost::shared_ptr<SessionData> session = m_sessionManager.GetSessionByUniquePlayerId(byPlayerId);
+	if (!session)
+		session = m_gameSessionManager.GetSessionByUniquePlayerId(byPlayerId);
+	if (session) {
+		boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+		packet->GetMsg()->present = PokerTHMessage_PR_reportGameAckMessage;
+		ReportGameAckMessage_t *netReportAck = &packet->GetMsg()->choice.reportGameAckMessage;
+		netReportAck->reportedGameId = reportedGameId;
+		netReportAck->reportGameResult = success ? reportGameResult_gameReportAccepted : reportGameResult_gameReportInvalid;
 		GetSender().Send(session, packet);
 	}
 }
