@@ -24,13 +24,23 @@ import org.junit.runners.Suite;
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses( {
+	AnnounceTest.class,
 	GuestLoginTest.class,
 	AuthLoginTest.class,
+	PlayerListTest.class,
+	GameListTest.class,
+	PlayerInfoTest.class,
+	LobbySubscriptionTest.class,
+	ChatTest.class,
 	CreateGameTest.class,
 	CreateRankingGameTest.class,
 	StartNormalGameTest.class,
 	RunNormalGameTest.class,
-	RunRankingGameTest.class
+	BlockedPlayerTest.class,
+	RunRankingGameTest.class,
+	RejoinGameTest.class,
+	RejoinMultiGameTest.class,
+	SeatStateTest.class
 })
 public class AllTests {
 	public static void main(String[] args)
